@@ -10,13 +10,13 @@ _wvtop="$(pwd)"
 wvmktempdir ()
 {
     local script_name="$(basename $0)"
-    mkdir -p "$_wvtop/t/tmp" || exit $?
-    mktemp -d "$_wvtop/t/tmp/$script_name-XXXXXXX" || exit $?
+    mkdir -p "$_wvtop/test/tmp" || exit $?
+    mktemp -d "$_wvtop/test/tmp/$script_name-XXXXXXX" || exit $?
 }
 
 wvmkmountpt ()
 {
     local script_name="$(basename $0)"
-    mkdir -p "$_wvtop/t/mnt" || exit $?
-    mktemp -d "$_wvtop/t/mnt/$script_name-XXXXXXX" || exit $?
+    mkdir -p "$_wvtop/test/mnt" || exit $?
+    mktemp -d "$_wvtop/test/mnt/$script_name-XXXXXXX" || exit $?
 }
